# SPDX-FileCopyrightText: 2023-present Trenton H <rda0128ou@mozmail.com>
#
# SPDX-License-Identifier: MPL-2.0

from typing import Final

# Only compress content which is larger than this
MIN_COMPRESS_LEN: Final[int] = 1024
